==> xcsoar-6.8.17.tar.xz: xcsoar-6.8.17/src/Device/Driver/FLARM/Settings.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "Device.hpp"
#include "NMEA/Derived.hpp"

#include <stdio.h>

#ifdef _UNICODE
#include <windows.h>
#endif

bool
FlarmDevice::SendSetting(const char *name, const char *value,
                         OperationEnvironment &env)
{
  assert(name != nullptr);
  assert(value != nullptr);

  /* erase the old value from the settings map, because we expect to
     receive the new one now */
  settings.Lock();
  settings.erase(name);
  settings.Unlock();

  char buffer[64];
  sprintf(buffer, "PFLAC,S,%s,%s", name, value);
  return Send(buffer, env);
}

bool
FlarmDevice::RequestSetting(const char *name, OperationEnvironment &env)
{
  char buffer[64];
  sprintf(buffer, "PFLAC,R,%s", name);
  return Send(buffer, env);
}

std::pair<bool, std::string>
FlarmDevice::GetSetting(const char *name) const
{
  ScopeLock protect(settings);
  auto i = settings.find(name);
  if (i == settings.end())
    return std::make_pair(false, std::string());

  return std::make_pair(true, *i);
}

==> xcsoar-7.9.tar.xz: xcsoar-7.9/src/Device/Driver/FLARM/Settings.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#include "Device.hpp"

#include <stdio.h>

#ifdef _UNICODE
#include <windows.h>
#endif

bool
FlarmDevice::SendSetting(const char *name, const char *value,
                         OperationEnvironment &env)
{
  assert(name != nullptr);
  assert(value != nullptr);

  /* erase the old value from the settings map, because we expect to
     receive the new one now */
  {
    const std::lock_guard<Mutex> lock(settings);
    settings.erase(name);
  }

  char buffer[64];
  sprintf(buffer, "PFLAC,S,%s,%s", name, value);
  return Send(buffer, env);
}

bool
FlarmDevice::RequestSetting(const char *name, OperationEnvironment &env)
{
  char buffer[64];
  sprintf(buffer, "PFLAC,R,%s", name);
  return Send(buffer, env);
}

std::pair<bool, std::string>
FlarmDevice::GetSetting(const char *name) const
{
  std::lock_guard<Mutex> lock(settings);
  auto i = settings.find(name);
  if (i == settings.end())
    return std::make_pair(false, std::string());

  return std::make_pair(true, *i);
}
